@@ -106,18 +106,25 @@ def main(testing=False, coverage_testing=False):
     # Coverage?
     omit = []
     if args.run_coverage:
+        if args.omit:
+            omit = args.omit.split(',')
+        else:
+            omit = [
+                '*/test*',
+                '*/termstyle*',
+                '*/mock*',
+                tempfile.gettempdir() + '*']
+            if (args.target != 'green') and (not args.target.startswith('green.')):
+                omit.extend([
+                '*Python.framework*',
+                '*site-packages*'])
         if not coverage:
             sys.stderr.write(
                 "Fatal: The 'coverage' module is not installed.  Have you "
                 "run 'pip install coverage'???")
             return 3
-        if args.subprocesses != 1:
-            sys.stderr.write(
-                "Warning: Running coverage for subprocesses is not yet "
-                "supported.  Setting subprocesses to 1.")
-            args.subprocesses = 1
         if (not testing) or coverage_testing:
-            cov = coverage.coverage()
+            cov = coverage.coverage(data_file='.coverage', omit=omit)
             cov.start()
 
 
@@ -131,7 +138,8 @@ def main(testing=False, coverage_testing=False):
 
     stream = GreenStream(sys.stderr, html = args.html)
     runner = GreenTestRunner(verbosity = args.verbose, stream = stream,
-            termcolor=args.termcolor, subprocesses=args.subprocesses)
+            termcolor=args.termcolor, subprocesses=args.subprocesses,
+            run_coverage=args.run_coverage, omit=omit)
 
     # Discover/Load the TestSuite
     tests  = getTests(args.target)
@@ -147,23 +155,14 @@ def main(testing=False, coverage_testing=False):
         result = lambda: None
         result.wasSuccessful = lambda: 0
     else:
-        result = runner.run(tests)
+        result = runner.run(tests) # pragma: no cover
 
     if args.run_coverage and ((not testing) or coverage_testing):
         stream.writeln()
         cov.stop()
-        if args.omit:
-            omit = args.omit.split(',')
-        else:
-            omit = [
-                '*/test*',
-                '*/termstyle*',
-                '*/mock*',
-                tempfile.gettempdir() + '*']
-            if (args.target != 'green') and (not args.target.startswith('green.')):
-                omit.extend([
-                '*Python.framework*',
-                '*site-packages*'])
+        cov.save()
+        cov.combine()
+        cov.save()
         cov.report(file=stream, omit=omit)
     return(int(not result.wasSuccessful()))
 
