@@ -1,100 +1,20 @@
 from __future__ import unicode_literals
 from __future__ import print_function
 from collections import OrderedDict
-import logging
-import multiprocessing
-from multiprocessing.pool import Pool
-import shutil
 import sys
-import tempfile
-import traceback
 
 from unittest.signals import registerResult
 from unittest import TestCase
 import warnings
 
-from green.loader import getTests
+try: # pragma: no cover
+    import coverage
+except: # pragma: no cover
+    coverage = None
+
 from green.output import GreenStream
-from green.result import ProtoTest, ProtoTestResult, GreenTestResult
-
-
-
-class SubprocessLogger(object):
-
-
-    def __init__(self, callable):
-        self.__callable = callable
-
-
-    def __call__(self, *args, **kwargs):
-        try:
-            result = self.__callable(*args, **kwargs)
-        except Exception:
-            # Here we add some debugging help. If multiprocessing's
-            # debugging is on, it will arrange to log the traceback
-            logger = multiprocessing.get_logger()
-            if not logger.handlers:
-                logger.addHandler(logging.StreamHandler())
-            logger.error(traceback.format_exc())
-            logger.handlers[0].flush()
-            # Re-raise the original exception so the Pool worker can
-            # clean up
-            raise
-
-        # It was fine, give a normal answer
-        return result
-
-
-
-class DaemonlessProcess(multiprocessing.Process):
-    # make 'daemon' attribute always return False
-    def _get_daemon(self):
-        return False
-    def _set_daemon(self, value):
-        pass
-    daemon = property(_get_daemon, _set_daemon)
-
-
-
-class LoggingDaemonlessPool(Pool):
-    Process = DaemonlessProcess
-
-
-    def apply_async(self, func, args=(), kwds={}, callback=None):
-        return Pool.apply_async(
-                self, SubprocessLogger(func), args, kwds, callback)
-
-
-
-def PoolRunner(test_name):
-    # Each pool worker gets his own temp directory, to avoid having tests that
-    # are used to taking turns using the same temp file name from interfering
-    # with eachother.  So long as the test doesn't use a hard-coded temp
-    # directory, anyway.
-    saved_tempdir = tempfile.tempdir
-    tempfile.tempdir = tempfile.mkdtemp()
-
-    # Create a structure to return the results of this one test
-    result = ProtoTestResult()
-    test = None
-    try:
-        test = getTests(test_name)
-        test.run(result)
-    except:
-        err = sys.exc_info()
-        if test:
-            result.addError(test, err)
-        else:
-            t             = ProtoTest()
-            t.module      = 'green.runner'
-            t.class_name  = 'N/A'
-            t.description = "Green's subprocess pool should function correctly."
-            t.method_name = 'PoolRunner'
-            result.addError(t, err)
-    # Restore the state of the temp directory
-    shutil.rmtree(tempfile.tempdir)
-    tempfile.tempdir = saved_tempdir
-    return result
+from green.result import GreenTestResult
+from green.subprocess import LoggingDaemonlessPool, PoolRunner
 
 
 
@@ -127,7 +47,8 @@ class GreenTestRunner():
 
 
     def __init__(self, stream=None, descriptions=True, verbosity=1,
-                 warnings=None, html=None, termcolor=None, subprocesses=0):
+                 warnings=None, html=None, termcolor=None, subprocesses=0,
+                 run_coverage=False, omit=[]):
         """
         stream - Any stream passed in will be wrapped in a GreenStream
         """
@@ -142,6 +63,8 @@ class GreenTestRunner():
         self.html = html
         self.termcolor = termcolor
         self.subprocesses = subprocesses or None
+        self.run_coverage = run_coverage
+        self.omit = omit
 
 
     def run(self, suite):
@@ -172,9 +95,13 @@ class GreenTestRunner():
                 pool = LoggingDaemonlessPool(processes=self.subprocesses)
                 if tests:
                     for class_name in tests:
-                        for test in tests[class_name]:
+                        for index, test in enumerate(tests[class_name]):
+                            if self.run_coverage:
+                                coverage_number = index + 1
+                            else:
+                                coverage_number = None
                             pool.apply_async(
-                                PoolRunner, (test,),
+                                PoolRunner, (test, coverage_number, self.omit),
                                 callback=result.addProtoTestResult)
                     pool.close()
                     pool.join()
