@@ -1,6 +1,9 @@
 from __future__ import unicode_literals
 import logging
+import os
+import shutil
 import sys
+import tempfile
 import unittest
 
 from green import cmdline
@@ -40,15 +43,6 @@ class TestMain(unittest.TestCase):
         del(self.saved_stderr)
         del(self.saved_stdout)
 
-    def test_coverageVsSubprocesses(self):
-        "'--subprocesses=(not 1) --run-coverage' is not currently supported"
-        cmdline.sys.argv = ['', '--subprocesses=2', '--run-coverage']
-        cmdline.main(testing=True)
-        self.assertIn('Warning', self.s.getvalue())
-        self.assertIn('not', self.s.getvalue())
-        self.assertIn('supported', self.s.getvalue())
-
-
     def test_optVersion(self):
         "--version causes a version string to be output"
         cmdline.sys.argv = ['', '--version']
@@ -91,9 +85,10 @@ class TestMain(unittest.TestCase):
         "If coverage and --run-coverage, then coverage is started"
         save_coverage = cmdline.coverage
         cmdline.coverage = MagicMock()
-        cmdline.sys.argv = ['', '--run-coverage']
+        cmdline.sys.argv = ['', '--run-coverage', '--omit=abc']
         cmdline.main(testing=True, coverage_testing=True)
-        cmdline.coverage.coverage.assert_called_with()
+        cmdline.coverage.coverage.assert_called_with(
+                data_file=u'.coverage', omit=['abc'])
         cmdline.coverage = save_coverage
 
 
@@ -119,3 +114,41 @@ class TestMain(unittest.TestCase):
         cmdline.coverage = save_coverage
 
 
+    def test_import_cmdline_module(self):
+        "The cmdline module can be imported"
+        global reload
+        try: # Python 3.x's reload is in importlib
+            import importlib
+            importlib.reload
+            reload = importlib.reload
+        except:
+            pass # Python 2.7's reload is builtin
+        reload(cmdline)
+
+
+
+class TestRunning(unittest.TestCase):
+
+    # Setup
+    @classmethod
+    def setUpClass(cls):
+        cls.startdir = os.getcwd()
+        cls.container_dir = tempfile.mkdtemp()
+
+
+    @classmethod
+    def tearDownClass(cls):
+        if os.getcwd() != cls.startdir:
+            os.chdir(cls.startdir)
+        cls.startdir = None
+        shutil.rmtree(cls.container_dir)
+
+
+    def setUp(self):
+        os.chdir(self.container_dir)
+        self.tmpdir = tempfile.mkdtemp(dir=self.container_dir)
+
+
+    def tearDown(self):
+        os.chdir(self.container_dir)
+        shutil.rmtree(self.tmpdir)
